@@ -6,9 +6,7 @@
 
 class DelayUi : public Gtk::Grid, public PluginUiBase {
  public:
-  DelayUi(BaseObjectType* cobject,
-          const Glib::RefPtr<Gtk::Builder>& builder,
-          const std::string& settings_name);
+  DelayUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
   virtual ~DelayUi();
 
  private:
