@@ -41,9 +41,7 @@ class EqualizerUi : public Gtk::Grid, public PluginUiBase {
 
   void on_nbands_changed();
 
-  void build_bands(Gtk::Grid* bands_grid,
-                   Glib::RefPtr<Gio::Settings> cfg,
-                   const int& nbands);
+  void build_bands(Gtk::Grid* bands_grid, Glib::RefPtr<Gio::Settings> cfg, const int& nbands);
 
   void build_unified_bands(const int& nbands);
 
