@@ -8,18 +8,14 @@
 
 class FilterUi : public Gtk::Grid, public PluginUiBase {
  public:
-  FilterUi(BaseObjectType* cobject,
-           const Glib::RefPtr<Gtk::Builder>& builder,
-           const std::string& settings_name);
+  FilterUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
   virtual ~FilterUi();
 
  private:
-  Glib::RefPtr<Gtk::Adjustment> input_gain, output_gain, frequency, resonance,
-      inertia;
+  Glib::RefPtr<Gtk::Adjustment> input_gain, output_gain, frequency, resonance, inertia;
 
   Gtk::ComboBoxText* mode;
-  Gtk::Button *preset_muted, *preset_disco, *preset_distant_headphones,
-      *preset_default;
+  Gtk::Button *preset_muted, *preset_disco, *preset_distant_headphones, *preset_default;
 
   void init_presets_buttons();
 };
