@@ -7,8 +7,7 @@ class GatePreset : public PluginPresetBase {
  public:
   GatePreset();
 
-  void write(PresetType preset_type,
-             boost::property_tree::ptree& root) override;
+  void write(PresetType preset_type, boost::property_tree::ptree& root) override;
   void read(PresetType preset_type, boost::property_tree::ptree& root) override;
 
  private:
