@@ -12,8 +12,7 @@ class Limiter : public PluginBase {
 
   GstElement* limiter = nullptr;
 
-  sigc::connection input_level_connection, output_level_connection,
-      attenuation_connection;
+  sigc::connection input_level_connection, output_level_connection, attenuation_connection;
 
   sigc::signal<void, std::array<double, 2>> input_level, output_level;
   sigc::signal<void, double> attenuation;
