@@ -3,19 +3,14 @@
 
 #include <gst/base/gstadapter.h>
 #include <gst/gst.h>
-#include <mutex>
 
 G_BEGIN_DECLS
 
 #define GST_TYPE_PEADAPTER (gst_peadapter_get_type())
-#define GST_PEADAPTER(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PEADAPTER, GstPeadapter))
-#define GST_PEADAPTER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PEADAPTER, GstPeadapterClass))
-#define GST_IS_PEADAPTER(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PEADAPTER))
-#define GST_IS_PEADAPTER_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PEADAPTER))
+#define GST_PEADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PEADAPTER, GstPeadapter))
+#define GST_PEADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PEADAPTER, GstPeadapterClass))
+#define GST_IS_PEADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PEADAPTER))
+#define GST_IS_PEADAPTER_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PEADAPTER))
 
 typedef struct _GstPeadapter GstPeadapter;
 typedef struct _GstPeadapterClass GstPeadapterClass;
@@ -42,8 +37,6 @@ struct _GstPeadapter {
   GstAdapter* adapter = nullptr;
   GstPad* srcpad = nullptr;
   GstPad* sinkpad = nullptr;
-
-  std::mutex lock_guard;
 };
 
 struct _GstPeadapterClass {
