@@ -94,22 +94,16 @@ void on_post_messages_changed(GSettings* settings, gchar* key, Compressor* l) {
 
 }  // namespace
 
-Compressor::Compressor(const std::string& tag, const std::string& schema)
-    : PluginBase(tag, "compressor", schema) {
-  compressor = gst_element_factory_make(
-      "lsp-plug-in-plugins-lv2-compressor-stereo", nullptr);
+Compressor::Compressor(const std::string& tag, const std::string& schema) : PluginBase(tag, "compressor", schema) {
+  compressor = gst_element_factory_make("lsp-plug-in-plugins-lv2-compressor-stereo", nullptr);
 
   if (is_installed(compressor)) {
-    auto audioconvert_in =
-        gst_element_factory_make("audioconvert", "compressor_audioconvert_in");
-    auto audioconvert_out =
-        gst_element_factory_make("audioconvert", "compressor_audioconvert_out");
+    auto audioconvert_in = gst_element_factory_make("audioconvert", "compressor_audioconvert_in");
+    auto audioconvert_out = gst_element_factory_make("audioconvert", "compressor_audioconvert_out");
 
-    gst_bin_add_many(GST_BIN(bin), audioconvert_in, compressor,
-                     audioconvert_out, nullptr);
+    gst_bin_add_many(GST_BIN(bin), audioconvert_in, compressor, audioconvert_out, nullptr);
 
-    gst_element_link_many(audioconvert_in, compressor, audioconvert_out,
-                          nullptr);
+    gst_element_link_many(audioconvert_in, compressor, audioconvert_out, nullptr);
 
     auto pad_sink = gst_element_get_static_pad(audioconvert_in, "sink");
     auto pad_src = gst_element_get_static_pad(audioconvert_out, "src");
@@ -128,8 +122,7 @@ Compressor::Compressor(const std::string& tag, const std::string& schema)
 
     bind_to_gsettings();
 
-    g_signal_connect(settings, "changed::post-messages",
-                     G_CALLBACK(on_post_messages_changed), this);
+    g_signal_connect(settings, "changed::post-messages", G_CALLBACK(on_post_messages_changed), this);
 
     // useless write just to force callback call
 
@@ -146,59 +139,44 @@ Compressor::~Compressor() {
 void Compressor::bind_to_gsettings() {
   g_settings_bind(settings, "mode", compressor, "cm", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "sidechain-listen", compressor, "scl",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "sidechain-listen", compressor, "scl", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "sidechain-type", compressor, "sct",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "sidechain-type", compressor, "sct", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "sidechain-mode", compressor, "scm",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "sidechain-mode", compressor, "scm", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "sidechain-source", compressor, "scs",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "sidechain-source", compressor, "scs", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind_with_mapping(settings, "input-gain", compressor, "g-in",
-                               G_SETTINGS_BIND_GET, util::db20_gain_to_linear,
+  g_settings_bind_with_mapping(settings, "input-gain", compressor, "g-in", G_SETTINGS_BIND_GET,
+                               util::db20_gain_to_linear, nullptr, nullptr, nullptr);
+
+  g_settings_bind_with_mapping(settings, "output-gain", compressor, "g-out", G_SETTINGS_BIND_GET,
+                               util::db20_gain_to_linear, nullptr, nullptr, nullptr);
+
+  g_settings_bind_with_mapping(settings, "attack", compressor, "at", G_SETTINGS_BIND_GET, util::double_to_float,
                                nullptr, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(settings, "output-gain", compressor, "g-out",
-                               G_SETTINGS_BIND_GET, util::db20_gain_to_linear,
+  g_settings_bind_with_mapping(settings, "release", compressor, "rt", G_SETTINGS_BIND_GET, util::double_to_float,
                                nullptr, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(settings, "attack", compressor, "at",
-                               G_SETTINGS_BIND_GET, util::double_to_float,
-                               nullptr, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "ratio", compressor, "cr", G_SETTINGS_BIND_GET, util::double_to_float, nullptr,
+                               nullptr, nullptr);
 
-  g_settings_bind_with_mapping(settings, "release", compressor, "rt",
-                               G_SETTINGS_BIND_GET, util::double_to_float,
-                               nullptr, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "threshold", compressor, "al", G_SETTINGS_BIND_DEFAULT,
+                               util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(settings, "ratio", compressor, "cr",
-                               G_SETTINGS_BIND_GET, util::double_to_float,
-                               nullptr, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "knee", compressor, "kn", G_SETTINGS_BIND_DEFAULT, util::db20_gain_to_linear,
+                               util::linear_gain_to_db20, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(
-      settings, "threshold", compressor, "al", G_SETTINGS_BIND_DEFAULT,
-      util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "makeup", compressor, "mk", G_SETTINGS_BIND_DEFAULT, util::db20_gain_to_linear,
+                               util::linear_gain_to_db20, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(
-      settings, "knee", compressor, "kn", G_SETTINGS_BIND_DEFAULT,
-      util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "sidechain-preamp", compressor, "scp", G_SETTINGS_BIND_DEFAULT,
+                               util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(
-      settings, "makeup", compressor, "mk", G_SETTINGS_BIND_DEFAULT,
-      util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "sidechain-reactivity", compressor, "scr", G_SETTINGS_BIND_GET,
+                               util::double_to_float, nullptr, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(
-      settings, "sidechain-preamp", compressor, "scp", G_SETTINGS_BIND_DEFAULT,
-      util::db20_gain_to_linear, util::linear_gain_to_db20, nullptr, nullptr);
-
-  g_settings_bind_with_mapping(
-      settings, "sidechain-reactivity", compressor, "scr", G_SETTINGS_BIND_GET,
-      util::double_to_float, nullptr, nullptr, nullptr);
-
-  g_settings_bind_with_mapping(
-      settings, "sidechain-lookahead", compressor, "sla", G_SETTINGS_BIND_GET,
-      util::double_to_float, nullptr, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings, "sidechain-lookahead", compressor, "sla", G_SETTINGS_BIND_GET,
+                               util::double_to_float, nullptr, nullptr, nullptr);
 }
