@@ -10,14 +10,10 @@
 G_BEGIN_DECLS
 
 #define GST_TYPE_PECONVOLVER (gst_peconvolver_get_type())
-#define GST_PECONVOLVER(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PECONVOLVER, GstPeconvolver))
-#define GST_PECONVOLVER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PECONVOLVER, GstPeconvolverClass))
-#define GST_IS_PECONVOLVER(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PECONVOLVER))
-#define GST_IS_PECONVOLVER_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PECONVOLVER))
+#define GST_PECONVOLVER(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PECONVOLVER, GstPeconvolver))
+#define GST_PECONVOLVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PECONVOLVER, GstPeconvolverClass))
+#define GST_IS_PECONVOLVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PECONVOLVER))
+#define GST_IS_PECONVOLVER_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PECONVOLVER))
 
 typedef struct _GstPeconvolver GstPeconvolver;
 typedef struct _GstPeconvolverClass GstPeconvolverClass;
