@@ -1,8 +1,6 @@
 #include "delay_ui.hpp"
 
-DelayUi::DelayUi(BaseObjectType* cobject,
-                 const Glib::RefPtr<Gtk::Builder>& builder,
-                 const std::string& settings_name)
+DelayUi::DelayUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name)
     : Gtk::Grid(cobject), PluginUiBase(builder, settings_name) {
   name = "delay";
 
