@@ -1,8 +1,7 @@
 #include "exciter_preset.hpp"
 
 ExciterPreset::ExciterPreset()
-    : output_settings(Gio::Settings::create(
-          "com.github.wwmm.pulseeffects.sinkinputs.exciter")) {}
+    : output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs.exciter")) {}
 
 void ExciterPreset::save(boost::property_tree::ptree& root,
                          const std::string& section,
@@ -11,8 +10,7 @@ void ExciterPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".exciter.input-gain", settings->get_double("input-gain"));
 
-  root.put(section + ".exciter.output-gain",
-           settings->get_double("output-gain"));
+  root.put(section + ".exciter.output-gain", settings->get_double("output-gain"));
 
   root.put(section + ".exciter.amount", settings->get_double("amount"));
 
@@ -24,8 +22,7 @@ void ExciterPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".exciter.blend", settings->get_double("blend"));
 
-  root.put(section + ".exciter.ceil-active",
-           settings->get_boolean("ceil-active"));
+  root.put(section + ".exciter.ceil-active", settings->get_boolean("ceil-active"));
 
   root.put(section + ".exciter.listen", settings->get_boolean("listen"));
 }
@@ -35,16 +32,13 @@ void ExciterPreset::load(boost::property_tree::ptree& root,
                          const Glib::RefPtr<Gio::Settings>& settings) {
   update_key<bool>(root, settings, "state", section + ".exciter.state");
 
-  update_key<double>(root, settings, "input-gain",
-                     section + ".exciter.input-gain");
+  update_key<double>(root, settings, "input-gain", section + ".exciter.input-gain");
 
-  update_key<double>(root, settings, "output-gain",
-                     section + ".exciter.output-gain");
+  update_key<double>(root, settings, "output-gain", section + ".exciter.output-gain");
 
   update_key<double>(root, settings, "amount", section + ".exciter.amount");
 
-  update_key<double>(root, settings, "harmonics",
-                     section + ".exciter.harmonics");
+  update_key<double>(root, settings, "harmonics", section + ".exciter.harmonics");
 
   update_key<double>(root, settings, "scope", section + ".exciter.scope");
 
@@ -52,21 +46,18 @@ void ExciterPreset::load(boost::property_tree::ptree& root,
 
   update_key<double>(root, settings, "blend", section + ".exciter.blend");
 
-  update_key<bool>(root, settings, "ceil-active",
-                   section + ".exciter.ceil-active");
+  update_key<bool>(root, settings, "ceil-active", section + ".exciter.ceil-active");
 
   update_key<bool>(root, settings, "listen", section + ".exciter.listen");
 }
 
-void ExciterPreset::write(PresetType preset_type,
-                          boost::property_tree::ptree& root) {
+void ExciterPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     save(root, "output", output_settings);
   }
 }
 
-void ExciterPreset::read(PresetType preset_type,
-                         boost::property_tree::ptree& root) {
+void ExciterPreset::read(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     load(root, "output", output_settings);
   }
