@@ -2,9 +2,7 @@
 
 namespace {
 
-gboolean detection_enum_to_int(GValue* value,
-                               GVariant* variant,
-                               gpointer user_data) {
+gboolean detection_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) {
   auto v = g_variant_get_string(variant, nullptr);
 
   if (v == std::string("RMS")) {
@@ -16,9 +14,7 @@ gboolean detection_enum_to_int(GValue* value,
   return true;
 }
 
-GVariant* int_to_detection_enum(const GValue* value,
-                                const GVariantType* expected_type,
-                                gpointer user_data) {
+GVariant* int_to_detection_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
   int v = g_value_get_int(value);
 
   if (v == 0) {
@@ -28,9 +24,7 @@ GVariant* int_to_detection_enum(const GValue* value,
   }
 }
 
-gboolean stereo_link_enum_to_int(GValue* value,
-                                 GVariant* variant,
-                                 gpointer user_data) {
+gboolean stereo_link_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) {
   auto v = g_variant_get_string(variant, nullptr);
 
   if (v == std::string("Average")) {
@@ -42,9 +36,7 @@ gboolean stereo_link_enum_to_int(GValue* value,
   return true;
 }
 
-GVariant* int_to_stereo_link_enum(const GValue* value,
-                                  const GVariantType* expected_type,
-                                  gpointer user_data) {
+GVariant* int_to_stereo_link_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
   int v = g_value_get_int(value);
 
   if (v == 0) {
@@ -56,9 +48,7 @@ GVariant* int_to_stereo_link_enum(const GValue* value,
 
 }  // namespace
 
-GateUi::GateUi(BaseObjectType* cobject,
-               const Glib::RefPtr<Gtk::Builder>& builder,
-               const std::string& settings_name)
+GateUi::GateUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name)
     : Gtk::Grid(cobject), PluginUiBase(builder, settings_name) {
   name = "gate";
 
@@ -90,15 +80,11 @@ GateUi::GateUi(BaseObjectType* cobject,
   settings->bind("release", release.get(), "value", flag);
   settings->bind("threshold", threshold.get(), "value", flag);
 
-  g_settings_bind_with_mapping(settings->gobj(), "detection", detection->gobj(),
-                               "active", G_SETTINGS_BIND_DEFAULT,
-                               detection_enum_to_int, int_to_detection_enum,
-                               nullptr, nullptr);
+  g_settings_bind_with_mapping(settings->gobj(), "detection", detection->gobj(), "active", G_SETTINGS_BIND_DEFAULT,
+                               detection_enum_to_int, int_to_detection_enum, nullptr, nullptr);
 
-  g_settings_bind_with_mapping(settings->gobj(), "stereo-link",
-                               stereo_link->gobj(), "active",
-                               G_SETTINGS_BIND_DEFAULT, stereo_link_enum_to_int,
-                               int_to_stereo_link_enum, nullptr, nullptr);
+  g_settings_bind_with_mapping(settings->gobj(), "stereo-link", stereo_link->gobj(), "active", G_SETTINGS_BIND_DEFAULT,
+                               stereo_link_enum_to_int, int_to_stereo_link_enum, nullptr, nullptr);
 }
 
 GateUi::~GateUi() {
