@@ -23,18 +23,14 @@ MaximizerUi::MaximizerUi(BaseObjectType* cobject,
   settings->bind("ceiling", ceiling.get(), "value", flag);
   settings->bind("release", release.get(), "value", flag);
   settings->bind("threshold", threshold.get(), "value", flag);
-
-  settings->set_boolean("post-messages", true);
 }
 
 MaximizerUi::~MaximizerUi() {
-  settings->set_boolean("post-messages", false);
-
   util::debug(name + " ui destroyed");
 }
 
 void MaximizerUi::on_new_reduction(double value) {
   reduction->set_value(value);
 
-  reduction_label->set_text(level_to_str(value));
+  reduction_label->set_text(level_to_str(value, 0));
 }
