@@ -1,10 +1,8 @@
 #include "pitch_preset.hpp"
 
 PitchPreset::PitchPreset()
-    : input_settings(Gio::Settings::create(
-          "com.github.wwmm.pulseeffects.sourceoutputs.pitch")),
-      output_settings(Gio::Settings::create(
-          "com.github.wwmm.pulseeffects.sinkinputs.pitch")) {}
+    : input_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sourceoutputs.pitch")),
+      output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs.pitch")) {}
 
 void PitchPreset::save(boost::property_tree::ptree& root,
                        const std::string& section,
@@ -23,8 +21,7 @@ void PitchPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".pitch.crispness", settings->get_int("crispness"));
 
-  root.put(section + ".pitch.formant-preserving",
-           settings->get_boolean("formant-preserving"));
+  root.put(section + ".pitch.formant-preserving", settings->get_boolean("formant-preserving"));
 
   root.put(section + ".pitch.faster", settings->get_boolean("faster"));
 }
@@ -34,11 +31,9 @@ void PitchPreset::load(boost::property_tree::ptree& root,
                        const Glib::RefPtr<Gio::Settings>& settings) {
   update_key<bool>(root, settings, "state", section + ".pitch.state");
 
-  update_key<double>(root, settings, "input-gain",
-                     section + ".pitch.input-gain");
+  update_key<double>(root, settings, "input-gain", section + ".pitch.input-gain");
 
-  update_key<double>(root, settings, "output-gain",
-                     section + ".pitch.output-gain");
+  update_key<double>(root, settings, "output-gain", section + ".pitch.output-gain");
 
   update_key<double>(root, settings, "cents", section + ".pitch.cents");
 
@@ -48,14 +43,12 @@ void PitchPreset::load(boost::property_tree::ptree& root,
 
   update_key<int>(root, settings, "crispness", section + ".pitch.crispness");
 
-  update_key<bool>(root, settings, "formant-preserving",
-                   section + ".pitch.formant-preserving");
+  update_key<bool>(root, settings, "formant-preserving", section + ".pitch.formant-preserving");
 
   update_key<bool>(root, settings, "faster", section + ".pitch.faster");
 }
 
-void PitchPreset::write(PresetType preset_type,
-                        boost::property_tree::ptree& root) {
+void PitchPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     save(root, "output", output_settings);
   } else {
@@ -63,8 +56,7 @@ void PitchPreset::write(PresetType preset_type,
   }
 }
 
-void PitchPreset::read(PresetType preset_type,
-                       boost::property_tree::ptree& root) {
+void PitchPreset::read(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     load(root, "output", output_settings);
   } else {
