@@ -1,7 +1,6 @@
 #include "plugin_ui_base.hpp"
 
-PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder,
-                           const std::string& settings_name)
+PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name)
     : settings(Gio::Settings::create(settings_name)) {
   builder->get_widget("enable", enable);
   builder->get_widget("listbox_control", listbox_control);
@@ -22,10 +21,8 @@ PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder,
 
   // gsettings bindings
 
-  connections.push_back(
-      settings->signal_changed("state").connect([=](auto key) {
-        settings->set_boolean("post-messages", settings->get_boolean(key));
-      }));
+  connections.push_back(settings->signal_changed("state").connect(
+      [=](auto key) { settings->set_boolean("post-messages", settings->get_boolean(key)); }));
 
   auto flag = Gio::SettingsBindFlags::SETTINGS_BIND_DEFAULT;
   auto flag_get = Gio::SettingsBindFlags::SETTINGS_BIND_GET;
@@ -55,18 +52,15 @@ std::string PluginUiBase::level_to_str(const double& value, const int& places) {
 }
 
 void PluginUiBase::on_new_input_level(const std::array<double, 2>& peak) {
-  update_level(input_level_left, input_level_left_label, input_level_right,
-               input_level_right_label, peak);
+  update_level(input_level_left, input_level_left_label, input_level_right, input_level_right_label, peak);
 
   if (peak[0] > 1 || peak[1] > 1) {
     input_saturated = true;
 
-    img_state->set_from_icon_name("dialog-warning-symbolic",
-                                  Gtk::ICON_SIZE_BUTTON);
+    img_state->set_from_icon_name("dialog-warning-symbolic", Gtk::ICON_SIZE_BUTTON);
   } else if (peak[0] <= 1 && peak[1] <= 1) {
     if (input_saturated) {
-      img_state->set_from_icon_name("emblem-ok-symbolic",
-                                    Gtk::ICON_SIZE_BUTTON);
+      img_state->set_from_icon_name("emblem-ok-symbolic", Gtk::ICON_SIZE_BUTTON);
     }
 
     input_saturated = false;
@@ -74,23 +68,19 @@ void PluginUiBase::on_new_input_level(const std::array<double, 2>& peak) {
 }
 
 void PluginUiBase::on_new_output_level(const std::array<double, 2>& peak) {
-  update_level(output_level_left, output_level_left_label, output_level_right,
-               output_level_right_label, peak);
+  update_level(output_level_left, output_level_left_label, output_level_right, output_level_right_label, peak);
 }
 
 void PluginUiBase::on_new_input_level_db(const std::array<double, 2>& peak) {
-  update_level_db(input_level_left, input_level_left_label, input_level_right,
-                  input_level_right_label, peak);
+  update_level_db(input_level_left, input_level_left_label, input_level_right, input_level_right_label, peak);
 
   if (peak[0] > 0 || peak[1] > 0) {
     input_saturated = true;
 
-    img_state->set_from_icon_name("dialog-warning-symbolic",
-                                  Gtk::ICON_SIZE_BUTTON);
+    img_state->set_from_icon_name("dialog-warning-symbolic", Gtk::ICON_SIZE_BUTTON);
   } else if (peak[0] <= 0 && peak[1] <= 0) {
     if (input_saturated) {
-      img_state->set_from_icon_name("emblem-ok-symbolic",
-                                    Gtk::ICON_SIZE_BUTTON);
+      img_state->set_from_icon_name("emblem-ok-symbolic", Gtk::ICON_SIZE_BUTTON);
     }
 
     input_saturated = false;
@@ -98,6 +88,5 @@ void PluginUiBase::on_new_input_level_db(const std::array<double, 2>& peak) {
 }
 
 void PluginUiBase::on_new_output_level_db(const std::array<double, 2>& peak) {
-  update_level_db(output_level_left, output_level_left_label,
-                  output_level_right, output_level_right_label, peak);
+  update_level_db(output_level_left, output_level_left_label, output_level_right, output_level_right_label, peak);
 }
