@@ -3,9 +3,7 @@
 #include <boost/process.hpp>
 #include "util.hpp"
 
-PulseInfoUi::PulseInfoUi(BaseObjectType* cobject,
-                         const Glib::RefPtr<Gtk::Builder>& builder,
-                         PulseManager* pm_ptr)
+PulseInfoUi::PulseInfoUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, PulseManager* pm_ptr)
     : Gtk::Box(cobject), pm(pm_ptr) {
   builder->get_widget("stack", stack);
   builder->get_widget("server_name", server_name);
@@ -23,28 +21,20 @@ PulseInfoUi::PulseInfoUi(BaseObjectType* cobject,
   builder->get_widget("listbox_resamplers", listbox_resamplers);
   builder->get_widget("config_file", config_file);
 
-  listbox_modules->set_sort_func(
-      sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
+  listbox_modules->set_sort_func(sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
 
-  listbox_clients->set_sort_func(
-      sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
+  listbox_clients->set_sort_func(sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
 
-  listbox_config->set_sort_func(
-      sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
+  listbox_config->set_sort_func(sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
 
-  listbox_resamplers->set_sort_func(
-      sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
+  listbox_resamplers->set_sort_func(sigc::mem_fun(*this, &PulseInfoUi::on_listbox_sort));
 
-  stack->connect_property_changed(
-      "visible-child",
-      sigc::mem_fun(*this, &PulseInfoUi::on_stack_visible_child_changed));
+  stack->connect_property_changed("visible-child", sigc::mem_fun(*this, &PulseInfoUi::on_stack_visible_child_changed));
 
-  connections.push_back(
-      pm->server_changed.connect([=]() { update_server_info(); }));
+  connections.push_back(pm->server_changed.connect([=]() { update_server_info(); }));
 
   connections.push_back(pm->module_info.connect([=](auto info) {
-    auto b = Gtk::Builder::create_from_resource(
-        "/com/github/wwmm/pulseeffects/ui/module_info.glade");
+    auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/module_info.glade");
 
     Gtk::ListBoxRow* row;
     Gtk::Label *module_name, *module_argument;
@@ -62,8 +52,7 @@ PulseInfoUi::PulseInfoUi(BaseObjectType* cobject,
   }));
 
   connections.push_back(pm->client_info.connect([=](auto info) {
-    auto b = Gtk::Builder::create_from_resource(
-        "/com/github/wwmm/pulseeffects/ui/client_info.glade");
+    auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/client_info.glade");
 
     Gtk::ListBoxRow* row;
     Gtk::Label *client_name, *client_binary;
@@ -98,8 +87,7 @@ PulseInfoUi::~PulseInfoUi() {
 }
 
 PulseInfoUi* PulseInfoUi::add_to_stack(Gtk::Stack* stack, PulseManager* pm) {
-  auto builder = Gtk::Builder::create_from_resource(
-      "/com/github/wwmm/pulseeffects/ui/pulse_info.glade");
+  auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/pulse_info.glade");
 
   PulseInfoUi* ui;
 
@@ -165,71 +153,80 @@ void PulseInfoUi::on_stack_visible_child_changed() {
 }
 
 void PulseInfoUi::get_pulse_conf() {
-  boost::process::ipstream pipe_stream;
-  boost::process::child c("pulseaudio --dump-conf",
-                          boost::process::std_out > pipe_stream);
+  std::string command = "pulseaudio --dump-conf";
 
-  std::string line;
+  try {
+    boost::process::ipstream pipe_stream;
+    boost::process::child c(command, boost::process::std_out > pipe_stream);
 
-  while (pipe_stream && std::getline(pipe_stream, line) && !line.empty()) {
-    std::vector<std::string> aux;
-    std::string key, value;
+    std::string line;
 
-    boost::split(aux, line, boost::is_any_of("="));
+    while (pipe_stream && std::getline(pipe_stream, line) && !line.empty()) {
+      std::vector<std::string> aux;
+      std::string key, value;
 
-    if (aux.size() > 1) {
-      auto b = Gtk::Builder::create_from_resource(
-          "/com/github/wwmm/pulseeffects/ui/pulse_conf_file_line.glade");
-
-      Gtk::ListBoxRow* row;
-      Gtk::Label *conf_key, *conf_value;
-
-      b->get_widget("conf_row", row);
-      b->get_widget("conf_key", conf_key);
-      b->get_widget("conf_value", conf_value);
-
-      row->set_name(aux[0]);
-      conf_key->set_text(aux[0]);
-      conf_value->set_text(aux[1]);
-
-      listbox_config->add(*row);
-    } else {
-      boost::split(aux, line, boost::is_any_of(":"));
+      boost::split(aux, line, boost::is_any_of("="));
 
       if (aux.size() > 1) {
-        std::string tmp = aux[1];
+        auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/pulse_conf_file_line.glade");
 
-        boost::split(aux, tmp, boost::is_any_of("#"));
+        Gtk::ListBoxRow* row;
+        Gtk::Label *conf_key, *conf_value;
 
-        config_file->set_text(aux[0]);
+        b->get_widget("conf_row", row);
+        b->get_widget("conf_key", conf_key);
+        b->get_widget("conf_value", conf_value);
+
+        row->set_name(aux[0]);
+        conf_key->set_text(aux[0]);
+        conf_value->set_text(aux[1]);
+
+        listbox_config->add(*row);
+      } else {
+        boost::split(aux, line, boost::is_any_of(":"));
+
+        if (aux.size() > 1) {
+          std::string tmp = aux[1];
+
+          boost::split(aux, tmp, boost::is_any_of("#"));
+
+          config_file->set_text(aux[0]);
+        }
       }
     }
-  }
 
-  // c.wait();
-  listbox_config->show_all();
+    // c.wait();
+    listbox_config->show_all();
+  } catch (std::exception& e) {
+    util::warning(log_tag + command + " : " + e.what());
+  }
 }
 
 void PulseInfoUi::get_resamplers() {
-  boost::process::ipstream pipe_stream;
-  boost::process::child c("pulseaudio --dump-resample-methods",
-                          boost::process::std_out > pipe_stream);
+  std::string command = "pulseaudio --dump-resample-methods";
 
-  std::string line;
+  try {
+    boost::process::ipstream pipe_stream;
+    boost::process::child c(command, boost::process::std_out > pipe_stream);
 
-  while (pipe_stream && std::getline(pipe_stream, line) && !line.empty()) {
-    auto row = Gtk::manage(new Gtk::ListBoxRow());
-    auto label = Gtk::manage(new Gtk::Label());
+    std::string line;
 
-    row->set_name(line);
+    while (pipe_stream && std::getline(pipe_stream, line) && !line.empty()) {
+      auto row = Gtk::manage(new Gtk::ListBoxRow());
+      auto label = Gtk::manage(new Gtk::Label());
 
-    label->set_text(line);
-    label->set_halign(Gtk::Align::ALIGN_START);
+      row->set_name(line);
 
-    row->add(*label);
+      label->set_text(line);
+      label->set_halign(Gtk::Align::ALIGN_START);
 
-    listbox_resamplers->add(*row);
+      row->add(*label);
+
+      listbox_resamplers->add(*row);
+    }
+
+    listbox_resamplers->show_all();
+  } catch (std::exception& e) {
+    util::warning(log_tag + command + " : " + e.what());
   }
-
-  listbox_resamplers->show_all();
 }
