@@ -2,9 +2,7 @@
 #include <glibmm/main.h>
 #include "util.hpp"
 
-Webrtc::Webrtc(const std::string& tag,
-               const std::string& schema,
-               const int& sampling_rate)
+Webrtc::Webrtc(const std::string& tag, const std::string& schema, const int& sampling_rate)
     : PluginBase(tag, "webrtc", schema), rate(sampling_rate) {
   webrtc = gst_element_factory_make("webrtcdsp", nullptr);
 
@@ -37,8 +35,7 @@ void Webrtc::build_probe_bin() {
   auto probe = gst_element_factory_make("webrtcechoprobe", nullptr);
   auto sink = gst_element_factory_make("fakesink", nullptr);
 
-  auto props = gst_structure_from_string(
-      "props,application.name=PulseEffectsWebrtcProbe", nullptr);
+  auto props = gst_structure_from_string("props,application.name=PulseEffectsWebrtcProbe", nullptr);
 
   auto caps_str = "audio/x-raw,format=S16LE,channels=2,rate=48000";
   auto caps = gst_caps_from_string(caps_str);
@@ -51,11 +48,9 @@ void Webrtc::build_probe_bin() {
   gst_structure_free(props);
   gst_caps_unref(caps);
 
-  gst_bin_add_many(GST_BIN(probe_bin), probe_src, queue, audioconvert,
-                   audioresample, capsfilter, probe, sink, nullptr);
+  gst_bin_add_many(GST_BIN(probe_bin), probe_src, queue, audioconvert, audioresample, capsfilter, probe, sink, nullptr);
 
-  gst_element_link_many(probe_src, queue, audioconvert, audioresample,
-                        capsfilter, probe, sink, nullptr);
+  gst_element_link_many(probe_src, queue, audioconvert, audioresample, capsfilter, probe, sink, nullptr);
 }
 
 void Webrtc::build_dsp_bin() {
@@ -68,11 +63,8 @@ void Webrtc::build_dsp_bin() {
   auto caps_out = gst_element_factory_make("capsfilter", nullptr);
   auto out_level = gst_element_factory_make("level", "webrtc_output_level");
 
-  auto capsin =
-      gst_caps_from_string("audio/x-raw,channels=2,format=S16LE,rate=48000");
-  auto capsout = gst_caps_from_string(
-      ("audio/x-raw,channels=2,format=F32LE,rate=" + std::to_string(rate))
-          .c_str());
+  auto capsin = gst_caps_from_string("audio/x-raw,channels=2,format=S16LE,rate=48000");
+  auto capsout = gst_caps_from_string(("audio/x-raw,channels=2,format=F32LE,rate=" + std::to_string(rate)).c_str());
 
   g_object_set(caps_in, "caps", capsin, nullptr);
   g_object_set(caps_out, "caps", capsout, nullptr);
@@ -82,13 +74,11 @@ void Webrtc::build_dsp_bin() {
 
   gst_bin_add(GST_BIN(bin), probe_bin);
 
-  gst_bin_add_many(GST_BIN(bin), in_level, audioconvert_in, audioresample_in,
-                   caps_in, webrtc, audioconvert_out, audioresample_out,
-                   caps_out, out_level, nullptr);
+  gst_bin_add_many(GST_BIN(bin), in_level, audioconvert_in, audioresample_in, caps_in, webrtc, audioconvert_out,
+                   audioresample_out, caps_out, out_level, nullptr);
 
-  gst_element_link_many(in_level, audioconvert_in, audioresample_in, caps_in,
-                        webrtc, audioconvert_out, audioresample_out, caps_out,
-                        out_level, nullptr);
+  gst_element_link_many(in_level, audioconvert_in, audioresample_in, caps_in, webrtc, audioconvert_out,
+                        audioresample_out, caps_out, out_level, nullptr);
 
   auto pad_sink = gst_element_get_static_pad(in_level, "sink");
   auto pad_src = gst_element_get_static_pad(out_level, "src");
@@ -99,10 +89,8 @@ void Webrtc::build_dsp_bin() {
   gst_object_unref(GST_OBJECT(pad_sink));
   gst_object_unref(GST_OBJECT(pad_src));
 
-  g_settings_bind(settings, "post-messages", in_level, "post-messages",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "post-messages", out_level, "post-messages",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "post-messages", in_level, "post-messages", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "post-messages", out_level, "post-messages", G_SETTINGS_BIND_DEFAULT);
 }
 
 void Webrtc::set_probe_src_device(std::string name) {
@@ -112,48 +100,35 @@ void Webrtc::set_probe_src_device(std::string name) {
 }
 
 void Webrtc::bind_to_gsettings() {
-  g_settings_bind(settings, "high-pass-filter", webrtc, "high-pass-filter",
+  g_settings_bind(settings, "high-pass-filter", webrtc, "high-pass-filter", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "echo-cancel", webrtc, "echo-cancel", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "echo-suppression-level", webrtc, "echo-suppression-level", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "noise-suppression", webrtc, "noise-suppression", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "noise-suppression-level", webrtc, "noise-suppression-level", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "gain-control", webrtc, "gain-control", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "extended-filter", webrtc, "extended-filter", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "delay-agnostic", webrtc, "delay-agnostic", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "target-level-dbfs", webrtc, "target-level-dbfs", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "compression-gain-db", webrtc, "compression-gain-db", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "limiter", webrtc, "limiter", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "voice-detection", webrtc, "voice-detection", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "gain-control-mode", webrtc, "gain-control-mode", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(settings, "voice-detection-frame-size-ms", webrtc, "voice-detection-frame-size-ms",
                   G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "echo-cancel", webrtc, "echo-cancel",
+  g_settings_bind(settings, "voice-detection-likelihood", webrtc, "voice-detection-likelihood",
                   G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "echo-suppression-level", webrtc,
-                  "echo-suppression-level", G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "noise-suppression", webrtc, "noise-suppression",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "noise-suppression-level", webrtc,
-                  "noise-suppression-level", G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "gain-control", webrtc, "gain-control",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "extended-filter", webrtc, "extended-filter",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "delay-agnostic", webrtc, "delay-agnostic",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "target-level-dbfs", webrtc, "target-level-dbfs",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "compression-gain-db", webrtc,
-                  "compression-gain-db", G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "limiter", webrtc, "limiter",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "voice-detection", webrtc, "voice-detection",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "gain-control-mode", webrtc, "gain-control-mode",
-                  G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "voice-detection-frame-size-ms", webrtc,
-                  "voice-detection-frame-size-ms", G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "voice-detection-likelihood", webrtc,
-                  "voice-detection-likelihood", G_SETTINGS_BIND_DEFAULT);
 }
